// Entry for all 3rd party library imports that do not rely on Bootstrap or NetBox styles.
@import '../node_modules/@mdi/font/css/materialdesignicons.min.css';
@import '../node_modules/flatpickr/dist/flatpickr.css';
@import '../node_modules/simplebar/dist/simplebar.css';
@import 'gridstack/dist/gridstack.min.css';
