{% extends 'generic/object.html' %}
{% load buttons %}
{% load custom_links %}
{% load helpers %}
{% load plugins %}

{% block breadcrumbs %}
<li class="breadcrumb-item"><a href="{% url 'plugins:netbox_proxbox:proxmoxendpoint' %}">Communities</a></li>
{% endblock %}


{% block content %}
<div class="row mb-3">
    <div class="col-md-4">
        <div class="card">
            <h5 class="card-header">
                Proxmox Endpoint
            </h5>
            <div class="card-body">
                <table class="table table-hover attr-table">
                    <tr>
                        <td>Name</td>
                        <td>{{ object.name }}</td>
                    </tr>
                    <tr>
                        <td>Host</td>
                        <td>{{ object.host }}</td>
                    </tr>
                    <tr>
                        <td>Mode</td>
                        <td>{{ object.mode }}</td>
                    </tr>
                    <tr>
                        <td>Version</td>
                        <td>{{ object.version }}</td>
                    </tr>
                </table>
            </div>
        </div>
        {% include 'inc/panels/custom_fields.html' %}
        {% include 'inc/panels/tags.html' %}
        {% include 'inc/panels/comments.html' %}
        {% plugin_left_page object %}
    </div>
    <div class="col-md-6">
        {% plugin_right_page object %}
    </div>
</div>
<div class="row">
    <div class="col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock %}