# Generated by Django 5.1.4 on 2025-01-20 01:25

"""Adjust FastAPI and NetBox endpoint name field defaults and metadata."""

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_proxbox', '0005_alter_proxmoxendpoint_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='fastapiendpoint',
            name='name',
            field=models.CharField(blank=True, default='ProxboxBox Endpoint', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='netboxendpoint',
            name='name',
            field=models.CharField(blank=True, default='NetBox Endpoint', max_length=255, null=True),
        ),
    ]
