{% extends 'base/layout.html' %}
{% load i18n %}

{% block content %}
    <div class="row mb-3">
        <div class="col col-md-6">
            <div class="card">
                <h5 class="card-header">Sync VM Backups</h5>
                <div class="card-body">
                    <p>Syncing backups...</p>
                    <p>{% trans "Track Proxbox sync runs in" %} <a href="{% url 'core:job_list' %}">{% trans "NetBox jobs" %}</a>.</p>
                    <p>If you want real-time updates of the sync process, consider enabling WebSocket in the <a href="{% url 'plugins:netbox_proxbox:fastapiendpoint_list' %}">FastAPI Endpoint</a> configuration.</p>
                </div>
            </div>
        </div>
    </div>

    <br>

    <button class="btn btn-primary" onclick="window.location.href='{% url 'plugins:netbox_proxbox:home' %}'">Return to Proxbox Homepage</button>
{% endblock %}