{% extends 'base/layout.html' %}
{% load form_helpers %}
{% load i18n %}

{% block title %}{% trans "Proxbox Settings" %}{% endblock %}

{% block content %}
<div class="row">
    <div class="col col-md-8">
        <div class="card">
            <h5 class="card-header">
                <i class="mdi mdi-cog"></i>
                {% trans "Plugin Settings" %}
            </h5>
            <div class="card-body">
                <p class="text-muted">
                    {% blocktrans trimmed %}
                    Configure runtime behavior for Proxbox synchronization.
                    {% endblocktrans %}
                </p>
                <form method="post">
                    {% csrf_token %}
                    {% render_field form.use_guest_agent_interface_name %}
                    {% render_field form.proxbox_fetch_max_concurrency %}
                    <div class="mt-3">
                        <button type="submit" class="btn btn-primary">
                            <i class="mdi mdi-content-save"></i>
                            {% trans "Save" %}
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
{% endblock %}
