{% extends 'base/layout.html' %}

{% block title %}{% endblock %}

{% block content %}
<div class="row my-5">
    <div class="col-6 offset-3">
        <div class="card">
            <h5 class="card-header text-danger">
                {{ request_path }}
            </h5>
            <div class="card-body">
                {% block message %}{% endblock %}
            </div>
            <div class="card-footer text-end">
                <a href="{% url 'home' %}" class="btn btn-sm btn-primary">Home Page</a>
            </div>
        </div>
    </div>
</div>
{% endblock %}