# Generated by Django 3.1.8 on 2021-04-19 18:02

"""Add a description field to the historical VM resources model."""

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_proxbox', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='vmresources',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
    ]
