// Base NetBox Theme Overrides and Settings - color mode agnostic.

@import '../node_modules/bootstrap/scss/functions';

$card-cap-bg: 'unset';

$border-radius-md: 0.375rem;
$border-radius-lg: 0.5rem;
$border-radius-xl: 0.75rem;
$border-radius-2xl: 1.5rem;

$border-radius: $border-radius-md;

$border-radius-sm: $border-radius;
$border-radius-lg: $border-radius-xl;

$badge-border-radius: $border-radius-md;
$progress-border-radius: $border-radius-md;

$font-weight-lighter: 200;
$font-weight-medium: 600;
$font-weight-bolder: 800;

$font-size-xs: 0.75rem;

$line-height-base: 1.5;
$line-height-xs: 1;
$line-height-sm: 1.25;
$line-height-lg: 1.75;

$darker: #1b1f22;
$darkest: #171b1d;

@import '../node_modules/bootstrap/scss/variables';

// This is the same value as the default from Bootstrap, but it needs to be in scope prior to
// importing _variables.scss from Bootstrap.
$btn-close-width: 1em;

$accordion-padding-y: 0.8125rem;
$accordion-padding-x: 0.8125rem;

$sidebar-width: 280px;
$sidebar-bottom-height: 4rem;

$transition-100ms-ease-in-out: all 0.1s ease-in-out;

// Sidebar/Sidenav
$sidenav-width-closed: 3rem;
$sidenav-width-open: 16rem;
$sidenav-icon-width: 2rem;
$sidenav-spacing-x: 1.5rem;
$sidenav-link-spacing-x: 1rem;
$sidenav-link-spacing-y: 0.5rem;
