"""Documentation capture helpers for the Proxbox CLI."""

from proxbox_cli.docgen.engine import CaptureEngine as CaptureEngine
from proxbox_cli.docgen.engine import build_command_catalog as build_command_catalog
from proxbox_cli.docgen.models import CaptureResult as CaptureResult
from proxbox_cli.docgen.models import CaptureSpec as CaptureSpec
