# Generated by Django 3.1.8 on 2021-04-19 23:30

"""Apply follow-up cleanup changes to the early VM resources schema."""

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('virtualization', '0019_standardize_name_length'),
        ('netbox_proxbox', '0002_vmresources_description'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='VmResources',
            new_name='ProxmoxVM',
        ),
    ]
